# React PDF viewer
A React component to view a PDF document.
It's written in TypeScript, and powered by React hooks completely.

~~~ javascript
// Core viewer
import { Viewer } from '@react-pdf-viewer/core';

// Plugins
import { defaultLayoutPlugin } from '@react-pdf-viewer/default-layout';

// Import styles
import '@react-pdf-viewer/core/lib/styles/index.css';
import '@react-pdf-viewer/default-layout/lib/styles/index.css';

// Create new plugin instance
const defaultLayoutPluginInstance = defaultLayoutPlugin();

<Viewer
    fileUrl='/assets/pdf-open-parameters.pdf'
    plugins={[
        // Register plugins
        defaultLayoutPluginInstance,
        ...
    ]}
/>
~~~

![React PDF viewer](https://raw.githubusercontent.com/phuoc-ng/react-pdf-viewer/master/assets/screenshot.png)

## Features

__Basic features__
* [x] Support password protected document
* [x] Zooming: Support custom levels such as actual size, page fit, and page width
* [x] Navigation between pages
* [x] Can go to the first and last pages quickly
* [x] Search for text
* [x] Preview page thumbnails
* [x] View and navigate the table of contents
* [x] List and download attachments
* [x] Rotating
* [x] Text selection and hand tool modes
* [x] Different scrolling modes
* [x] Full screen mode
* [x] Can open a file from local. Users can drag and drop a local file to view it
* [x] Download file
* [x] View the document properties
* [x] Support SSR
* [x] Print

__Customization__
* [x] The toolbar can be customized easily
* [x] All text items can be localized in another language

__Coming soon__
* [ ] Theming
* [ ] Darkmode

## License

You have to purchase a Commercial License at the [official website](https://react-pdf-viewer.dev).

## About

This project is developed by _Nguyen Huu Phuoc_. I love building products and sharing knowledge.

Be my friend on
* [Twitter](https://twitter.com/nghuuphuoc)
* [dev.to](https://dev.to/phuocng)
* [Github](https://github.com/phuoc-ng)

## Products

You might be interested in my products:

<table>
    <tbody>
        <tr valign="top">
            <td width="25%" align="center">
                <h3>1 LOC (3.3k★)</h3>
                <a href="https://1loc.dev">Favorite JavaScript utilities in single line of code</a>
            </td>
            <td width="25%" align="center">
                <h3>Blur Page</h3>
                <a href="https://blur.page">A browser extension to hide sensitive information on a web page</a>
            </td>
            <td width="25%" align="center">
                <h3>Check Browsers Support</h3>
                <a href="https://checkbrowsers.support">A browser extension to check browser compatibility without leaving your tab</a>
            </td>
            <td width="25%" align="center">
                <h3>CSS Layout (2.7k★)</h3>
                <a href="https://csslayout.io">A collection of popular layouts and patterns made with CSS</a>
            </td>
        </tr>
        <tr valign="top">
            <td width="25%" align="center">
                <h3>Fake Numbers</h3>
                <a href="https://fakenumbers.io">Generate fake and valid numbers</a>
            </td>
            <td width="25%" align="center">
                <h3>Form Validation</h3>
                <a href="https://formvalidation.io">The best validation library for JavaScript</a>
            </td>
            <td width="25%" align="center">
                <h3>HTML DOM (3.1k★)</h3>
                <a href="https://htmldom.dev">How to manage HTML DOM with vanilla JavaScript</a>
            </td>
            <td width="25%" align="center">
                <h3>React PDF Viewer</h3>
                <a href="https://react-pdf-viewer.dev">A React component to view a PDF document</a>
            </td>
        </tr>
        <tr valign="top">
            <td width="25%" align="center">
                <h3>this VS that</h3>
                <a href="https://thisthat.dev">The differences between ___ and ___ in the front-end development</a>
            </td>
            <td width="25%" align="center"></td>
            <td width="25%" align="center"></td>
            <td width="25%" align="center"></td>
        </tr>
    </tbody>
</table>
